@@ -12,6 +12,7 @@ from tastypie import http
 from tastypie.exceptions import NotFound, BadRequest, InvalidFilterError, HydrationError, InvalidSortError, ImmediateHttpResponse
 from oppia.models import Activity, Section, Tracker, Course, CourseDownload, Media, Schedule, ActivitySchedule, Cohort, Tag, CourseTag
 from oppia.api.serializers import PrettyJSONSerializer, CourseJSONSerializer, TagJSONSerializer, UserJSONSerializer
+from oppia.api.serializers import ModuleJSONSerializer
 from tastypie.models import ApiKey
 from tastypie.validation import Validation
 from django.http import HttpRequest
@@ -309,7 +310,21 @@ class CourseResource(ModelResource):
             bundle.data['schedule_uri'] = sr.get_resource_uri(schedule)
         
         return bundle
-  
+
+''' This is a temporary fix for any old urls being used 
+TODO: remove this after everyone has moved to new mobile app '''
+class ModuleResource(CourseResource): 
+     class Meta:
+        queryset = Course.objects.all()
+        resource_name = 'module'
+        allowed_methods = ['get']
+        fields = ['id', 'title', 'version', 'shortname']
+        authentication = ApiKeyAuthentication()
+        authorization = Authorization() 
+        serializer = ModuleJSONSerializer()
+        always_return_data = True
+        include_resource_uri = True
+    
 class CourseTagResource(ModelResource):
     course = fields.ToOneField('oppia.api.resources.CourseResource', 'course', full=True)
     class Meta:
