@@ -3,7 +3,7 @@ from django.contrib.auth.models import User
 from django.db import models
 from django.dispatch import Signal
 from oppia.models import Points, Award, Tracker, Activity, Section, Course, Cohort
-from tastypie.models import create_api_key
+from oppia.quiz.models import Quiz, QuizAttempt
 
 course_downloaded = Signal(providing_args=["course", "user"])
 
@@ -193,8 +193,8 @@ def badgeaward_callback(sender, **kwargs):
 course_downloaded.connect(course_download_callback)
 models.signals.post_save.connect(badgeaward_callback, sender=Award)
 models.signals.post_save.connect(tracker_callback, sender=Tracker)
-models.signals.post_save.connect(create_api_key, sender=User)
 models.signals.post_save.connect(signup_callback, sender=User)
-
+models.signals.post_save.connect(createquiz_callback, sender=Quiz)
+models.signals.post_save.connect(quizattempt_callback, sender=QuizAttempt)
 
 
